@@ -1,4 +1,4 @@
-# Gufw 9.10.2 - http://gufw.tuxfamily.org
+# Gufw 9.10.4 - http://gufw.tuxfamily.org
 # Copyright (C) 2009 Marcos Alvarez Costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -408,8 +408,10 @@ class Guigufw:
                 self.cb_ufw_level.set_active(0)
             elif self.firewall.ufw_log == self.variable.get_constant("ufw_log_medium"):
                 self.cb_ufw_level.set_active(1)
-            else:
+            elif self.firewall.ufw_log == self.variable.get_constant("ufw_log_high"):
                 self.cb_ufw_level.set_active(2)
+            else:
+                self.cb_ufw_level.set_active(3)
             
             
         if self.firewall.gufw_log != self.variable.get_constant("gufw_log_off"):
@@ -431,6 +433,8 @@ class Guigufw:
             self.firewall.set_ufw_log(self.variable.get_constant("ufw_log_medium"))
         elif ( self.cb_ufw_level.get_active() == 2 ) and ( self.firewall.ufw_log != self.variable.get_constant("ufw_log_high") ):
             self.firewall.set_ufw_log(self.variable.get_constant("ufw_log_high"))
+        elif ( self.cb_ufw_level.get_active() == 3 ) and ( self.firewall.ufw_log != self.variable.get_constant("ufw_log_full") ):
+            self.firewall.set_ufw_log(self.variable.get_constant("ufw_log_full"))
 
 
     # Open About Dialog
@@ -702,18 +706,22 @@ class Guigufw:
             if port_proto.find(self.variable.get_constant("tcp")) != -1:
                 port     = port_proto.replace(self.variable.get_constant("tcp"), "")
                 protocol = self.variable.get_constant("tcp")
+                l_service = self.variable.get_constant("service_no")
             elif port_proto.find(self.variable.get_constant("udp")) != -1:
                 port     = port_proto.replace(self.variable.get_constant("udp"), "")
                 protocol = self.variable.get_constant("udp")
+                l_service = self.variable.get_constant("service_no")
             elif port_proto.find(self.variable.get_constant("both")) != -1:
                 port     = port_proto.replace(self.variable.get_constant("both"), "")
                 protocol = self.variable.get_constant("both")
+                l_service = self.variable.get_constant("service_no")
             else:
                 port     = port_proto
                 protocol = ""
+                l_service = self.variable.get_constant("service_yes")
                 
             # TODO Add rule service
-            result = self.firewall.add_rule(self.variable.get_constant("service_yes"), action, protocol, "", "", "", port)
+            result = self.firewall.add_rule(l_service, action, protocol, "", "", "", port)
             if result.find(self.variable.get_constant("rule_added"))   != -1 or \
                 result.find(self.variable.get_constant("rule_updated")) != -1:
                 self.set_window_values(self.variable.get_text("013"))
